# ktabletconfig

A CLI utility to change tablet configuration on the [KDE Plasma Desktop](https://kde.org/plasma-desktop). This is meant to be used in situations not supported by the Drawing Tablet KCM, such as a automation or touching experimental settings not yet exposed in the GUI. **In most cases, you can do the same configuration in the KCM :-)**

This tool is similar to [gsetwacom for GNOME](https://github.com/linuxwacom/gsetwacom) or [xsetwacom used on the Plasma X11 session](https://github.com/linuxwacom/xf86-input-wacom).

## Usage

```shell
Usage: ktabletconfig [options]

Options:
  --list                           List connected tablets.
  --tablet <name>                  Set the name of the table to configure.
  --button <index>                 Set the index of the stylus button or pad
                                   button to configure.
  --left-handed                    Query the left-handed mode of the tablet.
  --orientation                    Query the orientation of the tablet.
  --output-name                    Query the output name of the tablet.
  --stylus-button <index>          Queries the keybinding of the stylus button.
  --pad-button <index>             Queries the keybinding of the pad button.
  --set-left-handed <on/off>       Sets the left-handed mode of the tablet.
  --set-orientation <orientation>  Sets the orientation of the tablet.
  --set-output-name <output-name>  Sets the output name of the tablet.
  --set-stylus-button <keybind>    Sets the keybinding of the stylus button.
  --set-pad-button <keybind>       Sets the keybinding of the pad button.
  -h, --help                       Displays help on commandline options.
  --help-all                       Displays help, including generic Qt options.
```

First you'll want to query the name of the tablet to configure, since that's used for most options.

```shell
$ ktabletconfig --list
UGTABLET 21.5 inch PenDisplay Stylus
```

A common scenario is to script the tablet to switch to a different display. First you'll need to figure out the names of your connectors via `kscreen-doctor -o`. Then plug that into `ktabletconfig`.

```shell
$ ktabletconfig --tablet "UGTABLET 21.5 inch PenDisplay Stylus" --set-output-name "HDMI-1" 
```

If you want to configure keybinds, set the `--button` option to select which button to configure. To set the first stylus button to "E", do something like this:

```shell
$ ktabletconfig --tablet "UGTABLET 21.5 inch PenDisplay Stylus" --button 0 --set-stylus-button "E" 
```

## Features

* Set and query many of the features available in the Drawing Tablet KCM:
  * Target output name
  * Orientation
  * Left-handed mode
  * Stylus & Pad keybindings

## Requirements

* KDE Plasma Desktop 6.0 or higher
  * Other versions of Plasma are unsupported. Only the Wayland session is supported.

## Notes

ktabletconfig intentionally does not support the same CLI interface as xsetwacom/gsetwacom, nor is it planned to. You will have to adapt your scripts.

Unlike xsetwacom, all modifications are **persistent** and will survive logouts/reboots etc. Modified settings will show up in the KCM and vice versa, so keep that in mind.

## Licensing and Credits

![GPLv3](https://www.gnu.org/graphics/gplv3-127x51.png)

This project is licensed under the GNU General Public License 3. This project uses some code from [Aleix Pol's kwin-inputdevice](https://invent.kde.org/apol/kwin-inputdevice).